@@ -1,3 +1,2 @@
-"isRgui" <-
-function ()
+isRgui <- function ()
 	(.Platform$GUI[1] == "Rgui")
