@@ -6,7 +6,7 @@ rmTemp <- function (x)
 	res <- rep(TRUE, l)
 	if (l > 1) names(res) <- x
 	for (i in 1:l) {
-		exst <- exists(x[i], env = TempEnv())
+		exst <- exists(x[i], env = TempEnv(), inherits = FALSE)
 		res0 <- try(if (exst) rm(list = x[i],
 			envir = TempEnv()), silent = TRUE)
 		if (!exst || inherits(res0, "try-error")) res[i] <- FALSE
